==> stargazer_1.0.tar.gz: stargazer/man/stargazer_style_list.Rd <==
\name{stargazer_style_list}
\alias{list of supported styles}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{List of supported styles for \code{\link{stargazer}}
%%  ~~function to do ... ~~
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
The following character strings can be used in the \code{style} argument of the \code{\link{stargazer}} command. Most styles are designed to resemble an existing academic journal, as listed below.
}

\section{}{

\tabular{ll}{
  \code{"all"} \tab publish every statistic available, incl. t-statistics and p-values \cr
  \code{"all2"} \tab {same as \code{"all"}, but omitting t-statistics and p-values} \cr
  \code{"default"} \tab default: publish regression coefficients with standard errors, and the most commonly reported statistics \cr
  \code{"commadefault"} \tab like \code{"default"}, but uses a decimal comma and a single space to separate thousands \cr
  \code{"aer"} \tab American Economic Review \cr
  \code{"ajps"} \tab American Journal of Political Science \cr
  \code{"ajs"} \tab American Journal of Sociology \cr
  \code{"asq"} \tab Administrative Science Quarterly \cr
  \code{"asr"} \tab American Sociological Review \cr
  \code{"apsr"} \tab American Political Science Review \cr
  \code{"demography"} \tab Demography \cr
  \code{"io"} \tab International Organization \cr
  \code{"jpam"} \tab Journal of Policy Analysis and Management \cr
  \code{"qje"} \tab Quarterly Journal of Economics \cr
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
}
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line

==> stargazer_4.5.3.tar.gz: stargazer/man/stargazer_style_list.Rd <==
\name{stargazer_style_list}
\alias{list of supported styles}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{stargazer: list of supported styles
%%  ~~function to do ... ~~
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
The following character strings can be used in the \code{style} argument of the \code{\link{stargazer}} command. Most styles are designed to resemble an existing academic journal, as listed below.
}

\section{}{

\tabular{ll}{
  \code{"all"} \tab publish every statistic available, incl. t-statistics and p-values \cr
  \code{"all2"} \tab {same as \code{"all"}, but omitting t-statistics and p-values} \cr
  \code{"default"} \tab default: publish regression coefficients with standard errors, and the most commonly reported statistics \cr
  \code{"commadefault"} \tab like \code{"default"}, but uses a decimal comma and a single space to separate thousands \cr
  \code{"aer"} \tab American Economic Review \cr
  \code{"ajps"} \tab American Journal of Political Science \cr
  \code{"ajs"} \tab American Journal of Sociology \cr
  \code{"asq"} \tab Administrative Science Quarterly \cr
  \code{"asr"} \tab American Sociological Review \cr
  \code{"apsr"} \tab American Political Science Review \cr
  \code{"demography"} \tab Demography \cr
  \code{"io"} \tab International Organization \cr
  \code{"jpam"} \tab Journal of Policy Analysis and Management \cr
  \code{"qje"} \tab Quarterly Journal of Economics \cr
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
}
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line
